@@ -1,11 +1,11 @@
-from xl_docx.compiler.processors.component import ComponentProcessor
+from xl_docx.mixins.component import ComponentMixin
 
 
 
 def test_new():
-    processor = ComponentProcessor()
+    processor = ComponentMixin()
     xml = '<xl-check condition="2>1">content</xl-check>'
-    result = processor.compile(xml)
+    result = processor.process_components(xml)
     expected = '($ if 2>1 $)content($ endif $)'
     assert result == expected
 
@@ -13,20 +13,20 @@ def test_new():
 def test_basic_component():
     """Test basic component functionality"""
     # Process XML
-    processor = ComponentProcessor()
+    processor = ComponentMixin()
 
     xml = '''<xl-text content="123" style="color: red"/>'''
-    result = processor.compile(xml)
+    result = processor.process_components(xml)
     assert result == '<xl-p style="color: red">123</xl-p>'
 
 
     xml = '''<xl-text content="123"/>'''
-    result = processor.compile(xml)
+    result = processor.process_components(xml)
     assert result == '<xl-p>123</xl-p>'
 
 
     xml = '''<xl-text style="color: red"/>'''
-    result = processor.compile(xml)
+    result = processor.process_components(xml)
     assert result == '<xl-p style="color: red"></xl-p>'
 
     
